==> haskell-aeson-diff-1.1.0.13-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-diff
version:              1.1.0.13
visibility:           public
id:                   aeson-diff-1.1.0.13-CE73LxWkxZv8EkEnJUkt3Q
key:                  aeson-diff-1.1.0.13-CE73LxWkxZv8EkEnJUkt3Q
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Thomas Sutton
homepage:             https://github.com/ysangkok/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  f5c73456c2fcb2a4a4db7d9c27a7ce2b
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-diff
hs-libraries:         HSaeson-diff-1.1.0.13-CE73LxWkxZv8EkEnJUkt3Q
depends:
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC base-4.17.2.1
    bytestring-0.11.5.3
    edit-distance-vector-1.0.0.4-IdAI7hjbPNx1MZcnQIalfm
    scientific-0.3.8.0-KXoba1fOMYH676R2WXZfYW text-2.0.2
    vector-0.13.2.0-CQ8QMV1t4PN5YFZtNXivGS

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-diff-1.1.0.13-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-diff
version:              1.1.0.13
visibility:           public
id:                   aeson-diff-1.1.0.13-8SeQIwwnGEI13YWkInRbqt
key:                  aeson-diff-1.1.0.13-8SeQIwwnGEI13YWkInRbqt
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Thomas Sutton
homepage:             https://github.com/ysangkok/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  151c909289c8e4867fba1f4839754fd4
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-diff-1.1.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-diff
hs-libraries:         HSaeson-diff-1.1.0.13-8SeQIwwnGEI13YWkInRbqt
depends:
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC base-4.17.2.1
    bytestring-0.11.5.3
    edit-distance-vector-1.0.0.4-IdAI7hjbPNx1MZcnQIalfm
    scientific-0.3.8.0-KXoba1fOMYH676R2WXZfYW text-2.0.2
    vector-0.13.2.0-CQ8QMV1t4PN5YFZtNXivGS

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
